@@ -14,6 +14,8 @@
 #'
 #' @return [ggplot2::ggplot()] object.
 #'
+#' @template section_theme
+#'
 #' @references
 #' `r format_bib("ggfortify")`
 #'
@@ -37,7 +39,11 @@
 #' autoplot(learner)
 #' }
 autoplot.LearnerClassifGlmnet = function(object, ...) { # nolint
-  plot_ggfortify(object, ...)
+  plot_ggfortify(object, ...) +
+    apply_theme(list(
+      scale_color_viridis_d("Feature", end = 0.8),
+      theme_mlr3()
+    ))
 }
 
 #' @export
