@@ -1,3 +1,4 @@
+skip_if_not_installed("mlr3")
 skip_if_not_installed("mlr3cluster")
 skip_if_not_installed("factoextra")
 set.seed(42)
@@ -8,10 +9,10 @@ test_that("autoplot.LearnerClustHierarchical", {
   learner = mlr3::lrn("clust.agnes")$train(mlr3::tsk("usarrests"))
   p = autoplot(learner)
   expect_true(is.ggplot(p))
-  vdiffr::expect_doppelganger("learner_clust.agnes", p)
+  expect_doppelganger("learner_clust.agnes", p)
 
   learner = mlr3::lrn("clust.hclust")$train(mlr3::tsk("usarrests"))
   p = autoplot(learner, type = "scree")
   expect_true(is.ggplot(p))
-  vdiffr::expect_doppelganger("learner_clust.hclust", p)
+  expect_doppelganger("learner_clust.hclust", p)
 })
