@@ -1,3 +1,4 @@
+skip_if_not_installed("mlr3")
 skip_if_not_installed("mlr3cluster")
 skip_if_not_installed("clue")
 
@@ -11,13 +12,13 @@ test_that("autoplot.PredictionClust", {
 
   expect_warning(p <- autoplot(prediction, task, type = "scatter"), "Factor variables are omitted")
   expect_true(is.ggplot(p))
-  vdiffr::expect_doppelganger("predictionclust_scatter", p)
+  expect_doppelganger("predictionclust_scatter", p)
 
   p = autoplot(prediction, task, type = "sil")
   expect_true(is.ggplot(p))
-  vdiffr::expect_doppelganger("predictionclust_sil", p)
+  expect_doppelganger("predictionclust_sil", p)
 
   p = autoplot(prediction, task, type = "pca")
   expect_true(is.ggplot(p))
-  vdiffr::expect_doppelganger("predictionclust_pca", p)
+  expect_doppelganger("predictionclust_pca", p)
 })
